/**
 * This module implements the integration tests for AT commands client API.
 *
 * Copyright (C) Sierra Wireless Inc.
 *
 */

#include "legato.h"
#include "interfaces.h"

le_atClient_DeviceRef_t DevRef;

//--------------------------------------------------------------------------------------------------
/**
 * main of the test
 *
 */
//--------------------------------------------------------------------------------------------------
COMPONENT_INIT
{
    LE_INFO("Start the atClient");

    

    //! [DeviceBinding]
    //! [binding]
    int fd = open("/dev/ttyAT", O_RDWR | O_NOCTTY | O_NONBLOCK);

    LE_ASSERT(fd >= 0);

    int newFd = dup(fd);

    DevRef = le_atClient_Start(fd);
    //! [binding]

    // Try to stop the device
    LE_ASSERT(le_atClient_Stop(DevRef) == LE_OK);
    LE_ASSERT(le_atClient_Stop(DevRef) == LE_FAULT);

    DevRef = le_atClient_Start(newFd);

   
    char buffer[LE_ATDEFS_RESPONSE_MAX_BYTES];
    le_atClient_CmdRef_t cmdRef;

    //Setting UART1 for console
    cmdRef = le_atClient_Create();
    LE_ASSERT(le_atClient_SetDevice(cmdRef, DevRef) == LE_OK);
    LE_ASSERT(le_atClient_SetCommand(cmdRef, "at!mapuart=16,1") == LE_OK);
    LE_ASSERT(le_atClient_SetFinalResponse(cmdRef, "OK|ERROR") == LE_OK);
    //! [DeviceBinding]

    LE_ASSERT(le_atClient_Send(cmdRef) == LE_OK);
    LE_ASSERT(le_atClient_GetFinalResponse( cmdRef,buffer, LE_ATDEFS_RESPONSE_MAX_BYTES) == LE_OK);
    LE_INFO("Response for at!mapuart=16,1: %s", buffer);
    
    LE_ASSERT(le_atClient_Delete(cmdRef) == LE_OK);

    //Setting UART2 for linux app access
    cmdRef = le_atClient_Create();
    LE_ASSERT(le_atClient_SetDevice(cmdRef, DevRef) == LE_OK);
    LE_ASSERT(le_atClient_SetCommand(cmdRef, "at!mapuart=17,2") == LE_OK);
    LE_ASSERT(le_atClient_SetFinalResponse(cmdRef, "OK|ERROR") == LE_OK);
    //! [DeviceBinding]

    LE_ASSERT(le_atClient_Send(cmdRef) == LE_OK);
    LE_ASSERT(le_atClient_GetFinalResponse( cmdRef,buffer, LE_ATDEFS_RESPONSE_MAX_BYTES) == LE_OK);
    LE_INFO("Response for at!mapuart=17,2: %s", buffer);
    
    LE_ASSERT(le_atClient_Delete(cmdRef) == LE_OK);

    
    
    close(fd);
}
